@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2017 The Free Software Foundation, Inc.
+# Copyright (C) 2010-2018 by the Free Software Foundation, Inc.
 #
 # This file is part of mailmanclient.
 #
@@ -31,4 +31,4 @@ class Configuration(RESTDict):
         self.name = name
 
     def __repr__(self):
-        return '<Configuration: "{}">'.format(self.name)
+        return '<Configuration: {!r}>'.format(self.name)
