@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2017 The Free Software Foundation, Inc.
+# Copyright (C) 2010-2018 by the Free Software Foundation, Inc.
 #
 # This file is part of mailmanclient.
 #
@@ -26,7 +26,7 @@ class Queue(RESTObject):
     _properties = ('name', 'directory', 'files')
 
     def __repr__(self):
-        return '<Queue: {}>'.format(self.name)
+        return '<Queue: {!r}>'.format(self.name)
 
     def inject(self, list_id, text):
         self._connection.call(self._url, dict(list_id=list_id, text=text))
